@@ -9,11 +9,11 @@ VIM::Packager
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -21,7 +21,7 @@ our $VERSION = '0.01';
 
 =head1 DESCRIPTION
 
-** Under Developing **
+** UNDER DEVELOPING **
 
 =head1 FUNCTIONS
 
